from setuptools import setup

setup(name='youtea',
      version='0.1.5',
      description='Display statistics from youtube video',
      packages=['youtea'],
      author_email='leykoderto@gmail.com',
      long_description=open('README.md').read(),
      zip_safe=False)
